==> lima-swing-0.5-sources.jar: org/chorem/lima/ui/combobox/EntryBookComboBoxModel.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: EntryBookComboBoxModel.java 3051 2010-11-29 14:57:16Z echatellier $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.5/lima-swing/src/main/java/org/chorem/lima/ui/combobox/EntryBookComboBoxModel.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.combobox;

import java.util.List;
import javax.swing.AbstractListModel;
import javax.swing.ComboBoxModel;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.business.EntryBookServiceMonitorable;
import org.chorem.lima.business.ImportServiceMonitorable;
import org.chorem.lima.business.LimaException;
import org.chorem.lima.business.ServiceListener;
import org.chorem.lima.entity.EntryBook;
import org.chorem.lima.service.LimaServiceFactory;
import org.chorem.lima.ui.financialperiod.FinancialPeriodTableModel;

/**
 * Opened financial period combo box model.
 * 
 * @author chatellier
 * @version $Revision: 3051 $
 * 
 * Last update : $Date: 2010-11-29 15:57:16 +0100 (Mon, 29 Nov 2010) $
 * By : $Author: echatellier $
 */
public class EntryBookComboBoxModel extends AbstractListModel implements ComboBoxModel, ServiceListener {

    private static final long serialVersionUID = 1L;

    private static final Log log =
        LogFactory.getLog(FinancialPeriodTableModel.class);
    
    protected Object selectedEntryBook;
    
    protected EntryBookServiceMonitorable entryBookService;

    protected List<EntryBook> cacheDatas;
    
    public EntryBookComboBoxModel() {
        entryBookService =
            LimaServiceFactory.getInstance().getService(
                    EntryBookServiceMonitorable.class);
        entryBookService.addListener(this);
        LimaServiceFactory.getInstance().getService(
                ImportServiceMonitorable.class).addListener(this);
        cacheDatas = getDataList();
    }

    @Override
    public int getSize() {
            return cacheDatas.size();
    }

    @Override
    public Object getElementAt(int index) {
            return cacheDatas.get(index);
    }

    @Override
    public void setSelectedItem(Object anItem) {
        selectedEntryBook = anItem;
        fireContentsChanged(this, -1, -1);
    }

    @Override
    public Object getSelectedItem() {
        return selectedEntryBook;
    }
    
    /**
     * get the accounts list
     */
    public List<EntryBook> getDataList(){
       List<EntryBook> result = null;
       try {
           result = entryBookService.getAllEntryBooks();
       }
       catch (LimaException eee) {
           if (log.isDebugEnabled()){
               log.debug("Can't get list accounts", eee);
           }
       }
       return result;
    }
    
    
    public void refresh(){
        cacheDatas = getDataList();
        fireContentsChanged(this, 0, cacheDatas.size());
    }

    @Override
    public void notifyMethod(String serviceName, String methodeName) {
        if (methodeName.contains("EntryBook") || methodeName.contains("importAll")){
            refresh();
        }
    }
}

==> lima-swing-0.5.1-sources.jar: org/chorem/lima/ui/combobox/EntryBookComboBoxModel.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: EntryBookComboBoxModel.java 3278 2011-08-16 14:09:44Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.5.1/lima-swing/src/main/java/org/chorem/lima/ui/combobox/EntryBookComboBoxModel.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.combobox;

import java.util.List;
import javax.swing.AbstractListModel;
import javax.swing.ComboBoxModel;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.business.EntryBookServiceMonitorable;
import org.chorem.lima.business.ImportServiceMonitorable;
import org.chorem.lima.business.LimaException;
import org.chorem.lima.business.ServiceListener;
import org.chorem.lima.entity.EntryBook;
import org.chorem.lima.service.LimaServiceFactory;
import org.chorem.lima.ui.financialperiod.FinancialPeriodTableModel;

/**
 * Opened financial period combo box model.
 * 
 * @author chatellier
 * @version $Revision: 3278 $
 * 
 * Last update : $Date: 2011-08-16 16:09:44 +0200 (Tue, 16 Aug 2011) $
 * By : $Author: tchemit $
 */
public class EntryBookComboBoxModel extends AbstractListModel implements ComboBoxModel, ServiceListener {

    private static final long serialVersionUID = 1L;

    private static final Log log =
        LogFactory.getLog(FinancialPeriodTableModel.class);
    
    protected Object selectedEntryBook;
    
    protected EntryBookServiceMonitorable entryBookService;

    protected List<EntryBook> cacheDatas;
    
    public EntryBookComboBoxModel() {
        entryBookService =
            LimaServiceFactory.getInstance().getService(
                    EntryBookServiceMonitorable.class);
        entryBookService.addListener(this);
        LimaServiceFactory.getInstance().getService(
                ImportServiceMonitorable.class).addListener(this);
        cacheDatas = getDataList();
    }

    @Override
    public int getSize() {
            return cacheDatas.size();
    }

    @Override
    public Object getElementAt(int index) {
            return cacheDatas.get(index);
    }

    @Override
    public void setSelectedItem(Object anItem) {
        selectedEntryBook = anItem;
        fireContentsChanged(this, -1, -1);
    }

    @Override
    public Object getSelectedItem() {
        return selectedEntryBook;
    }
    
    /**
     * get the accounts list
     */
    public List<EntryBook> getDataList(){
       List<EntryBook> result = null;
       try {
           result = entryBookService.getAllEntryBooks();
       }
       catch (LimaException eee) {
           if (log.isDebugEnabled()){
               log.debug("Can't get list accounts", eee);
           }
       }
       return result;
    }
    
    
    public void refresh(){
        cacheDatas = getDataList();
        fireContentsChanged(this, 0, cacheDatas.size());
    }

    @Override
    public void notifyMethod(String serviceName, String methodeName) {
        if (methodeName.contains("EntryBook") || methodeName.contains("importAll")){
            refresh();
        }
    }
}
